pub enum ErrorCode {
Show 72 variants
ActorNotFound,
ArchiveNotReady,
ArmyNotFound,
DestinationNotFound,
DuplicateBoundaryWriter,
DuplicateDomainRecord,
DuplicateDomainRecordKind,
DuplicatePlugin,
DuplicatePluginCommand,
DuplicatePluginIngress,
DuplicatePluginSystem,
DuplicateStateOwner,
DuplicateReservationOfferer,
EntityNotFound,
DomainRecordNotFound,
DomainRecordReferenced,
DomainRecordVersionConflict,
InvalidAuthority,
InvalidArchive,
InvalidBoundary,
InvalidDecision,
InvalidDuration,
InvalidDomainRecord,
InvalidKnowledgeHolder,
InvalidKnowledgeRecord,
InvalidKnowledgeSchema,
InvalidKnowledgeAuthority,
KnowledgeLimitExceeded,
KnowledgeReadCutUnavailable,
KnowledgeRecordNotFound,
UndeclaredKnowledgeWrite,
EvidenceUnavailable,
EvidenceContentUnavailable,
DuplicateKnowledgeRecordKind,
InvalidRandomOperationEvidence,
RandomOperationConflict,
IdempotencyConflict,
InteractionReadOnly,
InvalidPayload,
InvalidPluginRegistration,
InvalidRandomDraw,
InvalidRandomStream,
InvalidRunConfiguration,
InvalidRunManifest,
InvalidSnapshot,
IdentifierExhausted,
LegacyReplayUnavailable,
LateIngress,
MissingIdempotencyKey,
MixedCommandIngress,
NoRoute,
PluginCommandNotFound,
PluginManifestMismatch,
PluginNotActive,
PluginPanicked,
PluginRegistrationClosed,
QueryBudgetExceeded,
ReplayMismatch,
ReplayEnvironmentMismatch,
SimulationRevisionConflict,
SimulationTimeConflict,
StaleSealToken,
StatePageUnavailable,
SynchronousReactionLimit,
UndeclaredRandomStream,
UndeclaredStateRead,
UndeclaredStateWrite,
UnsupportedSnapshotVersion,
UnsupportedRandomDrawAddress,
ValueOutOfRange,
IssuerUnavailable,
DecisionMakerUnavailable,
}Variants
ActorNotFound
ArchiveNotReady
ArmyNotFound
DestinationNotFound
DuplicateBoundaryWriter
DuplicateDomainRecord
DuplicateDomainRecordKind
DuplicatePlugin
DuplicatePluginCommand
DuplicatePluginIngress
DuplicatePluginSystem
DuplicateStateOwner
DuplicateReservationOfferer
EntityNotFound
DomainRecordNotFound
DomainRecordReferenced
DomainRecordVersionConflict
InvalidAuthority
InvalidArchive
InvalidBoundary
InvalidDecision
InvalidDuration
InvalidDomainRecord
InvalidKnowledgeHolder
InvalidKnowledgeRecord
InvalidKnowledgeSchema
InvalidKnowledgeAuthority
KnowledgeLimitExceeded
KnowledgeRecordNotFound
UndeclaredKnowledgeWrite
DuplicateKnowledgeRecordKind
InvalidRandomOperationEvidence
RandomOperationConflict
IdempotencyConflict
InteractionReadOnly
InvalidPayload
InvalidPluginRegistration
InvalidRandomDraw
InvalidRandomStream
InvalidRunConfiguration
InvalidRunManifest
InvalidSnapshot
IdentifierExhausted
LateIngress
MissingIdempotencyKey
MixedCommandIngress
NoRoute
PluginCommandNotFound
PluginManifestMismatch
PluginNotActive
PluginPanicked
PluginRegistrationClosed
QueryBudgetExceeded
ReplayMismatch
ReplayEnvironmentMismatch
SimulationRevisionConflict
SimulationTimeConflict
StaleSealToken
SynchronousReactionLimit
UndeclaredRandomStream
UndeclaredStateRead
UndeclaredStateWrite
UnsupportedSnapshotVersion
UnsupportedRandomDrawAddress
ValueOutOfRange
A command or decision issuer resolves to a person who is not alive or is detained or captive.
A decision maker resolves to a person who is not alive or is detained or captive.